==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Firehose/EncryptionConfiguration.pm <==
package Paws::Firehose::EncryptionConfiguration;
  use Moose;
  has KMSEncryptionConfig => (is => 'ro', isa => 'Paws::Firehose::KMSEncryptionConfig');
  has NoEncryptionConfig => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Firehose::EncryptionConfiguration

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Firehose::EncryptionConfiguration object:

  $service_obj->Method(Att1 => { KMSEncryptionConfig => $value, ..., NoEncryptionConfig => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Firehose::EncryptionConfiguration object:

  $result = $service_obj->Method(...);
  $result->Att1->KMSEncryptionConfig

=head1 DESCRIPTION

Describes the encryption for a destination in Amazon S3.

=head1 ATTRIBUTES


=head2 KMSEncryptionConfig => L<Paws::Firehose::KMSEncryptionConfig>

  The encryption key.


=head2 NoEncryptionConfig => Str

  Specifically override existing encryption information to ensure that no
encryption is used.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Firehose>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/Firehose/EncryptionConfiguration.pm <==
package Paws::Firehose::EncryptionConfiguration;
  use Moose;
  has KMSEncryptionConfig => (is => 'ro', isa => 'Paws::Firehose::KMSEncryptionConfig');
  has NoEncryptionConfig => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Firehose::EncryptionConfiguration

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Firehose::EncryptionConfiguration object:

  $service_obj->Method(Att1 => { KMSEncryptionConfig => $value, ..., NoEncryptionConfig => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Firehose::EncryptionConfiguration object:

  $result = $service_obj->Method(...);
  $result->Att1->KMSEncryptionConfig

=head1 DESCRIPTION

Describes the encryption for a destination in Amazon S3.

=head1 ATTRIBUTES


=head2 KMSEncryptionConfig => L<Paws::Firehose::KMSEncryptionConfig>

  The encryption key.


=head2 NoEncryptionConfig => Str

  Specifically override existing encryption information to ensure that no
encryption is used.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Firehose>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
